<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="551"/>
        <source>URI and driver do not match.</source>
        <translation>La URI y el controlador no coinciden.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="553"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>Instale hplip primero y reinicie la aplicación para volver a instalar el controlador.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="561"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>Seleccione un controlador hplip e inténtelo de nuevo.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="574"/>
        <source>URI can&apos;t be empty</source>
        <translation>La URI no puede estar vacía</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="581"/>
        <source> not found</source>
        <translation> no encontrado</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
        <source>Check printer settings</source>
        <translation>Comprobar los ajustes de la impresora</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
        <source>Checking printer settings...</source>
        <translation>Comprobando los ajustes de la impresora...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
        <source>Success</source>
        <translation>Con éxito</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>No se obtuvieron los atributos de la impresora, error: </translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
        <source>%1 is disabled</source>
        <translation>%1 está desactivado</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
        <source>is not accepting jobs</source>
        <translation>aún no acepta trabajos</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
        <source>Printer settings are ok</source>
        <translation>Los ajustes de la impresora son correctos</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
        <source>Check printer connection</source>
        <translation>Comprobar la conexión de la impresora</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
        <source>Checking printer connection...</source>
        <translation>Comprobando conexión de la impresora...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
        <source>Success</source>
        <translation>Con éxito</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>No se puede conectar a la impresora, error: %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
        <source> is not connected, URI: </source>
        <translation> no está conectado, URI: </translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
        <source>%1 does not exist</source>
        <translation>%1 no existe</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
        <source>Cannot connect to the printer</source>
        <translation>No se puede conectar a la impresora</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
        <source>The connection is valid</source>
        <translation>La conexión es válida</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
        <source>Check CUPS server</source>
        <translation>Comprobar el servidor CUPS</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
        <source>Checking CUPS server...</source>
        <translation>Comprobando del servidor CUPS...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
        <source>CUPS server is invalid</source>
        <translation>El servidor CUPS no es válido</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
        <source>CUPS server is valid</source>
        <translation>El servidor CUPS es válido</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
        <source>Checking driver...</source>
        <translation>Comprobando controlador...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
        <source>Success</source>
        <translation>Con éxito</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
        <source>PPD file %1 not found</source>
        <translation>Archivo PPD %1 no encontrado</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
        <source>The driver is damaged</source>
        <translation>El controlador está dañado</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
        <source>Driver filter %1 not found</source>
        <translation>Filtro del controlador %1 no encontrado</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 no está instalado, no se puede imprimir ahora</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
        <source>Driver is valid</source>
        <translation>El controlador es válido</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
        <source>Check driver</source>
        <translation>Comprobando controlador</translation>
    </message>
</context>
<context>
    <name>DPrinterSupplyShowDlg</name>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="166"/>
        <source>Low level</source>
        <translation>Nivel bajo</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="196"/>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="261"/>
        <source>Ink/Toner Status</source>
        <translation>Estado de la tinta/tóner</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="268"/>
        <source>Unknown amount</source>
        <translation>Cantidad desconocida</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="276"/>
        <source>Unable to get the remaining amount</source>
        <translation>No se puede obtener la cantidad restante</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="312"/>
        <source>The amounts are estimated, last updated at %1</source>
        <translation>Las cantidades son estimadas, actualizadas por última vez en %1</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="325"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>DPrinterTanslator</name>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="33"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="34"/>
        <location filename="../util/dprintertanslator.cpp" line="35"/>
        <source>Grayscale</source>
        <translation>Escala de grises</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="38"/>
        <location filename="../util/dprintertanslator.cpp" line="69"/>
        <location filename="../util/dprintertanslator.cpp" line="86"/>
        <location filename="../util/dprintertanslator.cpp" line="107"/>
        <location filename="../util/dprintertanslator.cpp" line="126"/>
        <location filename="../util/dprintertanslator.cpp" line="135"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="39"/>
        <location filename="../util/dprintertanslator.cpp" line="49"/>
        <source>Draft</source>
        <translation>Borrador</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="40"/>
        <location filename="../util/dprintertanslator.cpp" line="120"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="43"/>
        <location filename="../util/dprintertanslator.cpp" line="44"/>
        <location filename="../util/dprintertanslator.cpp" line="47"/>
        <source>Print Quality</source>
        <translation>Calidad de impresión</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="48"/>
        <location filename="../util/dprintertanslator.cpp" line="60"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="52"/>
        <location filename="../util/dprintertanslator.cpp" line="53"/>
        <location filename="../util/dprintertanslator.cpp" line="54"/>
        <source>Paper Source</source>
        <translation>Fuente de papel</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="55"/>
        <location filename="../util/dprintertanslator.cpp" line="56"/>
        <source>Auto-Select</source>
        <translation>Auto-selección</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="57"/>
        <location filename="../util/dprintertanslator.cpp" line="58"/>
        <source>Manual Feeder</source>
        <translation>Alimentador manual</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="59"/>
        <location filename="../util/dprintertanslator.cpp" line="73"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="61"/>
        <source>Drawer 1</source>
        <translation>Bandeja 1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="62"/>
        <source>Drawer 2</source>
        <translation>Bandeja 2</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="63"/>
        <source>Drawer 3</source>
        <translation>Bandeja 3</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="64"/>
        <source>Drawer 4</source>
        <translation>Bandeja 4</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="65"/>
        <source>Drawer 5</source>
        <translation>Bandeja 5</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="66"/>
        <source>Envelope Feeder</source>
        <translation>Alimentador de sobres</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="67"/>
        <source>Tray1</source>
        <translation>Bandeja1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="68"/>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="72"/>
        <source>MediaType</source>
        <translation>Tipo de papel</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="74"/>
        <source>Plain Paper</source>
        <translation>Papel normal</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="75"/>
        <source>Recycled Paper</source>
        <translation>Papel reciclado</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="76"/>
        <source>Color Paper</source>
        <translation>Papel de color</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="77"/>
        <source>Bond Paper</source>
        <translation>Papel adhesivo</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="78"/>
        <source>Heavy Paper 1</source>
        <translation>Papel grueso 1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="79"/>
        <source>Heavy Paper 2</source>
        <translation>Papel grueso 2</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="80"/>
        <source>Heavy Paper 3</source>
        <translation>Papel grueso 3</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="81"/>
        <location filename="../util/dprintertanslator.cpp" line="82"/>
        <source>OHP</source>
        <translation>OHP</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="83"/>
        <source>Labels</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="84"/>
        <source>Envelope</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="85"/>
        <source>Photo Paper</source>
        <translation>Papel fotográfico</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="89"/>
        <location filename="../util/dprintertanslator.cpp" line="90"/>
        <location filename="../util/dprintertanslator.cpp" line="91"/>
        <source>PageSize</source>
        <translation>Tamaño de la página</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="92"/>
        <source>Custom</source>
        <translation>Personalizar</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="95"/>
        <location filename="../util/dprintertanslator.cpp" line="96"/>
        <location filename="../util/dprintertanslator.cpp" line="97"/>
        <source>Duplex</source>
        <translation>Dúplex</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="98"/>
        <source>DuplexTumble</source>
        <translation>Dúplex en vertical</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="99"/>
        <source>DuplexNoTumble</source>
        <translation>Dúplex en horizontal</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="100"/>
        <source>ON (Long-edged Binding)</source>
        <translation>Activado (encuadernado en horizontal)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="101"/>
        <source>ON (Short-edged Binding)</source>
        <translation>Activado (encuadernado en vertical)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="102"/>
        <location filename="../util/dprintertanslator.cpp" line="103"/>
        <source>OFF</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="106"/>
        <location filename="../util/dprintertanslator.cpp" line="110"/>
        <source>Binding Edge</source>
        <translation>Margen de encuadernación</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="108"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="109"/>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="113"/>
        <source>Portrait (no rotation)</source>
        <translation>Retrato (sin rotación)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="114"/>
        <source>Landscape (90 degrees)</source>
        <translation>Panorámico (90 grados)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="115"/>
        <source>Reverse landscape (270 degrees)</source>
        <translation>Panorámico invertido (270 grados)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="116"/>
        <source>Reverse portrait (180 degrees)</source>
        <translation>Retrato invertido (180 grados)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="117"/>
        <source>Auto Rotation</source>
        <translation>Rotación automática</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="121"/>
        <source>Reverse</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="124"/>
        <location filename="../util/dprintertanslator.cpp" line="125"/>
        <source>Staple Location</source>
        <translation>Ubicación de las perforaciones</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="127"/>
        <source>Bind</source>
        <translation>Encuadernado</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="128"/>
        <source>Bind (none)</source>
        <translation>Encuadernado (ninguno)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="129"/>
        <source>Bind (bottom)</source>
        <translation>Encuadernado (inferior)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="130"/>
        <source>Bind (left)</source>
        <translation>Encuadernado (izquierdo)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="131"/>
        <source>Bind (right)</source>
        <translation>Encuadernado (derecho)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="132"/>
        <source>Bind (top)</source>
        <translation>Encuadernado (superior)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="136"/>
        <location filename="../util/dprintertanslator.cpp" line="137"/>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
</context>
<context>
    <name>DPrintersShowWindow</name>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="91"/>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="99"/>
        <source>Printers</source>
        <translation>Impresoras</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="104"/>
        <source>Add printer</source>
        <translation>Añadir impresora</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="107"/>
        <source>Delete printer</source>
        <translation>Quitar impresora</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="142"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="143"/>
        <source>Shared</source>
        <translation>Compartido</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="146"/>
        <source>Enabled</source>
        <translation>Activado</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="149"/>
        <source>Accept jobs</source>
        <translation>Aceptar trabajo</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="153"/>
        <source>Set as default</source>
        <translation>Establecer por defecto</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="166"/>
        <source>No Printers</source>
        <translation>Sin impresoras</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="193"/>
        <source>Location:</source>
        <translation>Ubicación:</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="198"/>
        <source>Model:</source>
        <translation>Modelo:</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="201"/>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="237"/>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="665"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="667"/>
        <source>Print Queue</source>
        <translation>Cola de impresión</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="670"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="672"/>
        <source>Print Test Page</source>
        <translation>Imprimir página de prueba</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="274"/>
        <source>Supplies</source>
        <translation>Suministros</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="310"/>
        <source>No printer configured</source>
        <translation>Sin impresoras configuradas</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="316"/>
        <source>Click + to add printers</source>
        <translation>Haga clic en + para añadir impresoras</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="365"/>
        <source>As print jobs are in process, you cannot rename the printer now, please try later</source>
        <translation>Como los trabajos de impresión están en proceso, no puede cambiar el nombre de la impresora ahora, intente más tarde</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="369"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="428"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="786"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="425"/>
        <source>CUPS server is not running, and can’t manage printers.</source>
        <translation>El servidor CUPS no se está ejecutando y no puede administrar impresoras.</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="692"/>
        <source>Idle</source>
        <translation>Inactiva</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="694"/>
        <source>Printing</source>
        <translation>Imprimiendo</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="696"/>
        <source>Disabled</source>
        <translation>Desabilitar</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="744"/>
        <source>Are you sure you want to delete the printer &quot;%1&quot; ?</source>
        <translation>¿Está seguro de que desea quitar la impresora «%1»?</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="750"/>
        <source>Delete</source>
        <translation>Quitar</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="782"/>
        <source>The name already exists</source>
        <translation>El nombre ya existe</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="801"/>
        <source>You will not be able to reprint the completed jobs if continue. Are you sure you want to rename the printer?</source>
        <translation>No podrá volver a imprimir los trabajos completados si continúa. ¿Está seguro de que desea cambiar el nombre de la impresora?</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="806"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="865"/>
        <source>The driver is damaged, please install it again.</source>
        <translation>El controlador está dañado, instálelo nuevamente.</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="868"/>
        <source>Install Driver</source>
        <translation>Instalar controlador</translation>
    </message>
</context>
<context>
    <name>DPropertySetDlg</name>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="261"/>
        <source>Print Properties</source>
        <translation>Propiedades de impresión</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="262"/>
        <source>Driver</source>
        <translation>Controlador</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="263"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="264"/>
        <source>Location</source>
        <translation>Ubicación</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="265"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="266"/>
        <source>Color Mode</source>
        <translation>Modo de color</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="267"/>
        <source>Orientation</source>
        <translation>Orientación</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="268"/>
        <source>Page Order</source>
        <translation>Orden de página</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="703"/>
        <source>Options conflict!</source>
        <translation>¡Conflicto de opciones!</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="706"/>
        <source>Please resolve the conflict first, and then save the changes.</source>
        <translation>Por favor, resuelva primero el conflicto y luego guarde los cambios.</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="725"/>
        <source>Conflict:</source>
        <translation>Conflicto:</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="736"/>
        <location filename="../ui/dpropertysetdlg.cpp" line="1234"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="1233"/>
        <source>Invalid URI</source>
        <translation>URI no válido</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1031"/>
        <source>EveryWhere driver</source>
        <translation>Todos los controladores</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="373"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>No se pudo encontrar la solución del controlador: %1, error: %2</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="384"/>
        <source>The solution is invalid</source>
        <translation>La solución no es válida.</translation>
    </message>
</context>
<context>
    <name>InstallDriverWindow</name>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="103"/>
        <location filename="../ui/installdriverwindow.cpp" line="107"/>
        <source>Select a driver from</source>
        <translation>Seleccione un controlador de</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="113"/>
        <location filename="../ui/installdriverwindow.cpp" line="116"/>
        <source>Local driver</source>
        <translation>Controlador local</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="118"/>
        <location filename="../ui/installdriverwindow.cpp" line="121"/>
        <source>Local PPD file</source>
        <translation>Archivo PPD local</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="123"/>
        <location filename="../ui/installdriverwindow.cpp" line="126"/>
        <source>Search for a driver</source>
        <translation>Buscar controlador</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="146"/>
        <location filename="../ui/installdriverwindow.cpp" line="464"/>
        <source>Choose a local driver</source>
        <translation>Secciona un controlador local</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="150"/>
        <source>Vendor</source>
        <translation>Fabricante</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="164"/>
        <source>Model</source>
        <translation>Modelo</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="177"/>
        <location filename="../ui/installdriverwindow.cpp" line="259"/>
        <source>Driver</source>
        <translation>Controlador</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="242"/>
        <source>Vendor and Model</source>
        <translation>Fabricante y modelo</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="244"/>
        <source>Enter a complete vendor and model (Only letters, numbers and whitespaces)</source>
        <translation>Ingrese un fabricante y modelo completos (Solo letras, números y espacios)</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="247"/>
        <source>Search</source>
        <comment>button</comment>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="296"/>
        <source>Install Driver</source>
        <comment>button</comment>
        <translation>Instalar controlador</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="446"/>
        <location filename="../ui/installdriverwindow.cpp" line="556"/>
        <source>Reselect</source>
        <translation>Cambiar</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="472"/>
        <location filename="../ui/installdriverwindow.cpp" line="553"/>
        <source>Select a PPD file</source>
        <translation>Seleccione un archivo PPD</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="481"/>
        <source>Search for printer driver</source>
        <translation>Buscar controlador de impresora</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="535"/>
        <source>(recommended)</source>
        <translation>(recomendado)</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="707"/>
        <source> (recommended)</source>
        <translation>(recomendado)</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="251"/>
        <source>is invalid</source>
        <translation>es invalido</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="280"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>No se pudo instalar el controlador llamando a la interfaz dbus</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="325"/>
        <source>Failed to install %1</source>
        <translation>Error al instalar %1</translation>
    </message>
</context>
<context>
    <name>InstallPrinterWindow</name>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="87"/>
        <location filename="../ui/installprinterwindow.cpp" line="163"/>
        <source>Installing driver...</source>
        <translation>Instalando controlador...</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="97"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="100"/>
        <location filename="../ui/installprinterwindow.cpp" line="186"/>
        <location filename="../ui/installprinterwindow.cpp" line="203"/>
        <source>View Printer</source>
        <comment>button</comment>
        <translation>Ver impresora</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="102"/>
        <location filename="../ui/installprinterwindow.cpp" line="188"/>
        <location filename="../ui/installprinterwindow.cpp" line="205"/>
        <source>Print Test Page</source>
        <comment>button</comment>
        <translation>Imprimir página de prueba</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="175"/>
        <source>Successfully installed </source>
        <translation>Instalado exitosamente</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="181"/>
        <location filename="../ui/installprinterwindow.cpp" line="199"/>
        <source>You have successfully added the printer. Print a test page to check if it works properly.</source>
        <translation>Ha añadido correctamente la impresora. Imprima una página de prueba para verificar si funciona correctamente.</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="193"/>
        <source>Printing test page...</source>
        <translation>Imprimiendo página de prueba...</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="210"/>
        <source>Did you print the test page successfully?</source>
        <translation>¿Imprimió la página de prueba con éxito?</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="216"/>
        <source>If succeeded, click Yes; if failed, click No</source>
        <translation>Cuando tiene éxito, haga clic en Sí; cuando falla, haga clic en No.</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="219"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="221"/>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="226"/>
        <location filename="../ui/installprinterwindow.cpp" line="246"/>
        <source>Print failed</source>
        <translation>La impresión falló</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="232"/>
        <source>Click Reinstall to install the printer driver again, or click Troubleshoot to start troubleshooting.</source>
        <translation>Haga clic en Reinstalar para instalar nuevamente el controlador de la impresora, o haga clic en Solucionar problemas para iniciar la solución de problemas.</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="235"/>
        <location filename="../ui/installprinterwindow.cpp" line="256"/>
        <source>Reinstall</source>
        <comment>button</comment>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="237"/>
        <location filename="../ui/installprinterwindow.cpp" line="258"/>
        <source>Troubleshoot</source>
        <comment>button</comment>
        <translation>Solucionar problemas</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="244"/>
        <source>Installation failed</source>
        <translation>La instalación falló</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="252"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="253"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="254"/>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="255"/>
        <source>Resume</source>
        <translation>Reanudar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="256"/>
        <source>Print first</source>
        <translation>Imprimir primero</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="257"/>
        <source>Reprint</source>
        <translation>Reimprimir</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="259"/>
        <source>No print jobs</source>
        <translation>No hay trabajos de impresión</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="405"/>
        <source>Are you sure you want to delete this job?</source>
        <translation>¿Está seguro que quiere borrar este trabajo?</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="411"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="412"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Quitar</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation> no encontrado</translation>
    </message>
</context>
<context>
    <name>JobManagerWindow</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1099"/>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1105"/>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1106"/>
        <source>Print Queue</source>
        <translation>Cola de impresión</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1107"/>
        <source>Completed</source>
        <translation>Completado</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1176"/>
        <source> failed</source>
        <translation>falló</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1197"/>
        <source>%1 jobs</source>
        <translation>%1 trabajos</translation>
    </message>
</context>
<context>
    <name>JobsDataModel</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="713"/>
        <source>Job</source>
        <translation>Trabajo</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="715"/>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="717"/>
        <source>Document</source>
        <translation>Documento</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="719"/>
        <source>Printer</source>
        <translation>Impresora</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="721"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="723"/>
        <source>Time submitted</source>
        <translation>Tiempo enviado</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="725"/>
        <source>Status</source>
        <translation>Stado</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="727"/>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
</context>
<context>
    <name>PermissionsWindow</name>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="48"/>
        <source>Connect to %1 to find a printer</source>
        <translation>Conectar a %1 para buscar impresora</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="74"/>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="76"/>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="78"/>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="92"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="93"/>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
</context>
<context>
    <name>PrinterApplication</name>
    <message>
        <location filename="../ui/printerapplication.cpp" line="104"/>
        <source>Print Manager</source>
        <translation>Impresoras</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="105"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>Impresoras de Deepin es una herramienta que permite añadir, quitar y configurar impresoras, administrar trabajos de impresión y más.</translation>
    </message>
</context>
<context>
    <name>PrinterSearchWindow</name>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="88"/>
        <location filename="../ui/printersearchwindow.cpp" line="91"/>
        <source>Discover printer</source>
        <translation>Detectar impresoras</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="94"/>
        <location filename="../ui/printersearchwindow.cpp" line="97"/>
        <source>Find printer</source>
        <translation>Buscar impresora</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="99"/>
        <location filename="../ui/printersearchwindow.cpp" line="102"/>
        <source>Enter URI</source>
        <translation>Ingresar URI</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="125"/>
        <source>Select a printer</source>
        <translation>Seleccionar una impresora</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="132"/>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="155"/>
        <location filename="../ui/printersearchwindow.cpp" line="268"/>
        <source>No printers found</source>
        <translation>No se han encontrado impresoras</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="202"/>
        <source>Install Driver</source>
        <translation>Instalar controlador</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="233"/>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="236"/>
        <source>Enter an address</source>
        <translation>Introduce una dirección</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="238"/>
        <source>Find</source>
        <comment>button</comment>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="346"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="351"/>
        <source>Enter device URI</source>
        <translation>Ingrese el URI del dispositivo</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="376"/>
        <source>Examples:</source>
        <translation>Ejemplo:</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="698"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="784"/>
        <source> (recommended)</source>
        <translation>(recomendado)</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="794"/>
        <source>The driver was found</source>
        <translation>El driver fue encontrado</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="795"/>
        <source>Connect to the network and try again</source>
        <translation>Conéctate a la red e inténtalo de nuevo</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="797"/>
        <source>Cannot find the driver</source>
        <translation>No se encuentra el controlador</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="798"/>
        <source>Please try to install it manually or search its official website</source>
        <translation>Por favor, intente instalarlo manualmente o busque en su sitio web oficial</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="808"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
        <source>Check test page printing</source>
        <translation>Verifica la pagina de prueba</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
        <source>Printing test page...</source>
        <translation>Imprimiendo pagina de prueba...</translation>
    </message>
</context>
<context>
    <name>PrinterTestPageDialog</name>
    <message>
        <location filename="../ui/printertestpagedialog.cpp" line="61"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="226"/>
        <source>Black</source>
        <translation>Negro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="227"/>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="228"/>
        <source>Brown</source>
        <translation>Marrón</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="229"/>
        <source>Cyan</source>
        <translation>Cian</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="230"/>
        <source>Dark-gray</source>
        <translation>Gris-oscuro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="231"/>
        <source>Dark gray</source>
        <translation>Gris oscuro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="232"/>
        <source>Dark-yellow</source>
        <translation>Amarillo-oscuro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="233"/>
        <source>Dark yellow</source>
        <translation>Amarillo oscuro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="234"/>
        <source>Gold</source>
        <translation>Dorado</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="235"/>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="236"/>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="237"/>
        <source>Light-black</source>
        <translation>Negro-claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="238"/>
        <source>Light black</source>
        <translation>Negro claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="239"/>
        <source>Light-cyan</source>
        <translation>Cian-claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="240"/>
        <source>Light cyan</source>
        <translation>Cian claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="241"/>
        <source>Light-gray</source>
        <translation>Gris-claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="242"/>
        <source>Light gray</source>
        <translation>Gris claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="243"/>
        <source>Light-magenta</source>
        <translation>Magenta-claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="244"/>
        <source>Light magenta</source>
        <translation>Magenta claro</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="245"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="246"/>
        <source>Orange</source>
        <translation>Naranja</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="247"/>
        <source>Red</source>
        <translation>Rojo</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="248"/>
        <source>Silver</source>
        <translation>Plata</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="249"/>
        <source>White</source>
        <translation>Blanco</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="250"/>
        <source>Yellow</source>
        <translation>Amarillo</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="251"/>
        <source>Waste</source>
        <translation>Residuo</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="108"/>
        <source>1 min ago</source>
        <translation>hace 1 min</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="111"/>
        <source>%1 mins ago</source>
        <translation>hace %1 mins</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="115"/>
        <source>1 hr ago</source>
        <translation>hace %1 hr</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="117"/>
        <source>%1 hrs ago</source>
        <translation>hace %1 hrs</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="122"/>
        <source>Yesterday</source>
        <translation>Ayer</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="124"/>
        <source>%1 days ago</source>
        <translation>hace %1 días</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="113"/>
        <source>Direct-attached Device</source>
        <translation>Dispositivo de conexión directa</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="114"/>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="616"/>
        <source>(use %1 protocol)</source>
        <translation>(usar protocolo %1)</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="26"/>
        <source>Select a driver</source>
        <translation>Seleccionar controlador</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="32"/>
        <source>Driver</source>
        <translation>Controlador</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="33"/>
        <source>Next</source>
        <comment>button</comment>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="34"/>
        <source>Install Driver</source>
        <comment>button</comment>
        <translation>Instalar controlador</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="36"/>
        <source>Drag a PPD file here 
 or</source>
        <translation>Arrastre un archivo PPD aquí 
o</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="37"/>
        <source>Select a PPD file</source>
        <comment>button</comment>
        <translation>Seleccione un archivo PPD</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="39"/>
        <source>Troubleshoot</source>
        <translation>Solución de problemas</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="40"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="43"/>
        <source>For more drivers, please refer to our official website: </source>
        <translation>Para obtener más controladores, consulte nuestro sitio web oficial: </translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="201"/>
        <source>Idle</source>
        <translation>Inactiva</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="204"/>
        <source>Printing</source>
        <translation>Imprimiendo</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="207"/>
        <source>Disabled</source>
        <translation>Desabilitar</translation>
    </message>
    <message>
        <location filename="../util/dprinter.cpp" line="285"/>
        <source>(recommended)</source>
        <translation>(recomendado)</translation>
    </message>
    <message>
        <location filename="../ui/dprinterpropertytemplate.h" line="33"/>
        <source>Preferences</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../Common/common.cpp" line="154"/>
        <source>%1 not found, please ask the administrator for help, or enter the printer IP address in URI of Properties.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RenamePrinterWindow</name>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="84"/>
        <source>Rename Printer</source>
        <translation>Renombrar impresora</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="91"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="93"/>
        <source>Location</source>
        <translation>Ubicación</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="95"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="106"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="107"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>ServerSettingsWindow</name>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="92"/>
        <source>Basic Server Settings</source>
        <translation>Ajustes básicos del servidor</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="101"/>
        <source>Publish shared printers connected to this system</source>
        <translation>Publicar impresoras compartidas conectadas a este sistema</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="103"/>
        <source>Allow printing from the Internet</source>
        <translation>Permitir impresión por Internet</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="105"/>
        <source>Allow remote administration</source>
        <translation>Permitir administración remota</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="107"/>
        <source>Save debugging information for troubleshooting</source>
        <translation>Guardar información de depuración para solución de problemas</translation>
    </message>
</context>
<context>
    <name>TroubleShootDialog</name>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="118"/>
        <source>Troubleshoot: </source>
        <translation>Solución de problemas:</translation>
    </message>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="145"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="178"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceptar</translation>
    </message>
</context>
</TS>